pub enum BuildError {
SymbolCountOver(u32, u32),
UnmatchedTextLength(usize, usize),
InvalidBlobSize(usize, usize),
NotAlignedBlob(usize, usize),
InvalidConfig(String),
}Expand description
Error type for the builder
Variants
SymbolCountOver(u32, u32)
The number of distinct symbols exceeds the capacity of the chosen block type.
UnmatchedTextLength(usize, usize)
The length of the provided text does not match the length declared during builder initialization.
InvalidBlobSize(usize, usize)
The provided blob slice has an incorrect size.
NotAlignedBlob(usize, usize)
The provided blob slice is not properly aligned.
InvalidConfig(String)
An invalid build configuration was provided.